package com.example.mmad.testapp.query;

import com.example.mmad.testapp.event.UserCreatedEvent;
import com.example.mmad.testapp.kafkaProducerConfig.KafkaProducerConfig;
import org.springframework.context.event.EventListener;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class UserQueryHandler {
    private static final String kafkaTopic = "user-created";
    private final KafkaProducerConfig kafkaProducer;

    public UserQueryHandler(KafkaProducerConfig kafkaProducer) {
        this.kafkaProducer = kafkaProducer;
    }

    @Async("taskExecutor")
    @EventListener
    public void handelUserCreated(UserCreatedEvent event) {
        kafkaProducer.kafkaTemplate().send(kafkaTopic, event);
        // persist in query data base
        System.out.println("Received user created event" + event.getUserId());
    }
}
